==> rnews-0.80.tar.gz: rnews-0.80/export.php <==
<?php
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

require_once('inc/config.php');
require_once('inc/security.php');
require_once('inc/functions.php');
require_once('inc/output.php');
require_once('inc/db.php');
require_once('inc/user.php');
require_once('inc/cat.php');
require_once('inc/feed.php');

$DEBUG = 0;

if (($UID = getUidFromCookie()) != NULL) {

  $db = new DB();
  $db->open() or die ("Unable to connect to database.");
  $user = new user ($db, $UID);
  if (!$user->valid) die ("Bad User.");

  //------------------------------------------------------------------
  if (isset($_REQUEST['opmlexp'])) {

    require_once('inc/opml.php');

    header ('Content-Type: application/opml+xml');
    header ('Content-Disposition: attachment; filename="rnews.opml"');

    $cat = NULL;
    if  (isset($_REQUEST['exportCat']) && intval($_REQUEST['exportCat']) > 0) {
      $cat = new category ($db, intval($_REQUEST['exportCat']), $user->userid);
      if (!$cat->valid)
        $cat = NULL;
    }
    echo exportOpml ($db, $user, $cat);
    exit(0);

  //------------------------------------------------------------------
  } elseif (isset($_REQUEST['opmlimp'])) {

    outputHeader ($user, 'OPML Import');
    outputNavigation ($db, $user);
    echo '<div id="wrapper"><div id="content">';
    echo checkInsecureFilePerms();
    echo '<div class="category">';

    if (!empty($_FILES['opmlfile']['tmp_name'])) {

      $file = $_FILES['opmlfile']['tmp_name'];
      if ($fp = fopen ($file, 'r')) {

        require_once('inc/opml.php');
        $opml = implode('', file($file));

        echo importOpml ($db, $user, $opml);
        echo '<p>You may go to <a href="'. defaultUrl($user) .'">your default category</a>, or use the menu at the left for navigation.</p>';

      } else {
        echo '<p>Server error opening OPML file.</p>';
      }
    } else {
      echo '<p>No file processed, please try again.</p>';
    }

  //------------------------------------------------------------------
  } else {

    outputHeader ($user, 'OPML Operations');
    outputNavigation ($db, $user);
    echo '<div id="wrapper"><div id="content">';
    echo checkInsecureFilePerms();
    echo '<div class="category">';
?>
  <p>OPML is a semi-standard format for sharing outlines and lists, and is used for blogrolls and RSS feeds.  Rnews can export to and import from this format, in particular, it can be used to upgrade from previous versions of the software.</p>
  <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="export">
    <fieldset>
      <legend>Export Feeds</legend>

      <p>Select the category of feeds to export to OPML format:</p>
      <select name="exportCat">
        <option value="0" selected="1">All Sources</option>
<?php
    $cats = category::all ($db, $user->userid, 'ORDER BY name');
    foreach ($cats as $cat) {
      echo '<option value="'. $cat->id .'">'.
        htmlspecialchars($cat->name, ENT_NOQUOTES) .'</option>';
    }
?>
      </select>
      <p><input type="submit" name="opmlexp" value="Export" /></p>
    </fieldset>
  </form>

  <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="import" enctype="multipart/form-data">
    <fieldset>
      <legend>Import Feeds</legend>

      <p>Select an OPML file to import feeds:</p>
      <p><input type="file" name="opmlfile" /></p>
      <p><input type="submit" name="opmlimp" value="Import" /></p>
    </fieldset>
  </form>

<?php
  }

  echo '</div></div></div>';

} else {
  redirectToLogin();
}

include('foot.php');
?>

==> rnews-0.81.tar.gz: rnews-0.81/export.php <==
<?php
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

require_once('inc/config.php');
require_once('inc/security.php');
require_once('inc/functions.php');
require_once('inc/output.php');
require_once('inc/db.php');
require_once('inc/user.php');
require_once('inc/cat.php');
require_once('inc/feed.php');

$DEBUG = 0;

if (($UID = getUidFromCookie()) != NULL) {

  $db = new DB();
  $db->open() or die ("Unable to connect to database.");
  $user = new user ($db, $UID);
  if (!$user->valid) die ("Bad User.");

  //------------------------------------------------------------------
  if (isset($_REQUEST['opmlexp'])) {

    require_once('inc/opml.php');

    $cat = NULL;
    if  (isset($_REQUEST['exportCat']) && intval($_REQUEST['exportCat']) > 0) {
      $cat = new category ($db, intval($_REQUEST['exportCat']), $user->userid);
      if (!$cat->valid)
        $cat = NULL;
      $catName = $cat->name;
    } else {
      $catName = 'All Sources';
    }

    header ('Content-Type: application/opml+xml');
    header ('Content-Disposition: attachment; filename="Rnews - '. $catName .'.opml"');

    echo exportOpml ($db, $user, $cat);
    exit(0);

  //------------------------------------------------------------------
  } elseif (isset($_REQUEST['opmlimp'])) {

    outputHeader ($user, 'OPML Import');
    outputNavigation ($db, $user);
    echo '<div id="wrapper"><div id="content">';
    echo checkInsecureFilePerms();
    echo '<div class="category">';

    if (!empty($_FILES['opmlfile']['tmp_name'])) {

      $file = $_FILES['opmlfile']['tmp_name'];
      if ($fp = fopen ($file, 'r')) {

        require_once('inc/opml.php');
        $opml = implode('', file($file));

        echo importOpml ($db, $user, $opml);
        echo '<p>You may go to <a href="'. defaultUrl($user) .'">your default category</a>, or use the menu at the left for navigation.</p>';

      } else {
        echo '<p>Server error opening OPML file.</p>';
      }
    } else {
      echo '<p>No file processed, please try again.</p>';
    }

  //------------------------------------------------------------------
  } else {

    outputHeader ($user, 'OPML Operations');
    outputNavigation ($db, $user);
    echo '<div id="wrapper"><div id="content">';
    echo checkInsecureFilePerms();
    echo '<div class="category">';
?>
  <p>OPML is a semi-standard format for sharing outlines and lists, and is used for blogrolls and RSS feeds.  Rnews can export to and import from this format, in particular, it can be used to upgrade from previous versions of the software.</p>
  <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="export">
    <fieldset>
      <legend>Export Feeds</legend>

      <p>Select the category of feeds to export to OPML format:</p>
      <select name="exportCat">
        <option value="0" selected="1">All Sources</option>
<?php
    $cats = category::all ($db, $user->userid, 'ORDER BY name');
    foreach ($cats as $cat) {
      echo '<option value="'. $cat->id .'">'.
        htmlspecialchars($cat->name, ENT_NOQUOTES) .'</option>';
    }
?>
      </select>
      <p><input type="submit" name="opmlexp" value="Export" /></p>
    </fieldset>
  </form>

  <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="POST" name="import" enctype="multipart/form-data">
    <fieldset>
      <legend>Import Feeds</legend>

      <p>Select an OPML file to import feeds:</p>
      <p><input type="file" name="opmlfile" /></p>
      <p><input type="submit" name="opmlimp" value="Import" /></p>
    </fieldset>
  </form>

<?php
  }

  echo '</div></div></div>';

} else {
  redirectToLogin();
}

include('foot.php');
?>
